<h1 align="center">Welcome to asktanya 👋</h1>
<p>
  <img alt="Version" src="https://img.shields.io/badge/version-1.0.4-blue.svg?cacheSeconds=2592000" />
  <a href="github.com/liviaellen/asktanya" target="_blank">
    <img alt="Documentation" src="https://img.shields.io/badge/documentation-yes-brightgreen.svg" />
  </a>
  <a href="#" target="_blank">
    <img alt="License: MIT License" src="https://img.shields.io/badge/License-MIT License-yellow.svg" />
  </a>
</p>

> Ask-tanya anything! Asktanya is a Python framework to search factual information on the internet.

### 🏠 [Homepage](liviaellen.com/asktanya)

### ✨ [Demo](liviaellen.com/asktanya)

## Install

```sh
pip install asktanya
```

## Usage

```sh
ask-tanya
```

## Author

👤 **Livia Ellen**

* Website: liviaellen.com
* Github: [@liviaellen](https://github.com/liviaellen)
* LinkedIn: [@liviaellen](https://linkedin.com/in/liviaellen)

## 🤝 Contributing

Contributions, issues and feature requests are welcome!<br />Feel free to check [issues page](https://github.com/liviaellen/asktanya/issues). 

## Show your support

Give a ⭐️ if this project helped you!

<a href="https://www.patreon.com/liviaellen">
  <img src="https://c5.patreon.com/external/logo/become_a_patron_button@2x.png" width="160">
</a>

***
_This README was generated with ❤️ by [readme-md-generator](https://github.com/kefranabg/readme-md-generator)_